@@ -24,7 +24,13 @@ dataframeToD3 <- function(df) {
   row.names(df) <- NULL
   lapply(seq_len(nrow(df)), function(row) {
     row <- df[row, , drop = FALSE]
-    lapply(row[, !is.na(row), drop = FALSE], as.character)
+    row_not_na <- row[, !is.na(row), drop = FALSE]
+    lapply(row_not_na, function(x) {
+      if (!lengths(x)) return(NA)
+      if (is.logical(x)) return(x)
+      if (lengths(x) > 1 | is.list(x)) return(lapply(unlist(x),as.character))
+      return(as.character(x))
+    })
   })
 }
 
